# Generated by roxygen2: do not edit by hand

S3method(c,uneval_parameters)
S3method(check_init,default)
S3method(check_init,quosures)
S3method(compute_counts,eval_matrix)
S3method(compute_counts,eval_part_surv)
S3method(copy_param_env,call)
S3method(copy_param_env,default)
S3method(copy_param_env,name)
S3method(copy_param_env,uneval_parameters)
S3method(define_surv_table,character)
S3method(define_surv_table,data.frame)
S3method(eval_surv,call)
S3method(eval_surv,character)
S3method(eval_surv,default)
S3method(eval_surv,flexsurvreg)
S3method(eval_surv,name)
S3method(eval_surv,quosure)
S3method(eval_surv,surv_add_haz)
S3method(eval_surv,surv_aft)
S3method(eval_surv,surv_dist)
S3method(eval_surv,surv_fit)
S3method(eval_surv,surv_model)
S3method(eval_surv,surv_ph)
S3method(eval_surv,surv_po)
S3method(eval_surv,surv_pooled)
S3method(eval_surv,surv_projection)
S3method(eval_surv,surv_shift)
S3method(eval_surv,surv_table)
S3method(eval_surv,survfit)
S3method(eval_transition,part_surv)
S3method(eval_transition,uneval_matrix)
S3method(expand_state,uneval_inflow)
S3method(expand_state,uneval_init)
S3method(expand_state,uneval_matrix)
S3method(expand_state,uneval_state_list)
S3method(fn_calibrate,run_model)
S3method(fn_calibrate,updated_model)
S3method(get_central_strategy,combined_model)
S3method(get_central_strategy,default)
S3method(get_central_strategy,psa)
S3method(get_central_strategy,run_model)
S3method(get_counts,combined_model)
S3method(get_counts,eval_strategy)
S3method(get_counts,list)
S3method(get_counts,run_model)
S3method(get_counts,updated_model)
S3method(get_cycles,combined_model)
S3method(get_cycles,psa)
S3method(get_cycles,run_model)
S3method(get_eval_inflow,eval_strategy)
S3method(get_eval_init,combined_model)
S3method(get_eval_init,eval_strategy)
S3method(get_frontier,combined_model)
S3method(get_frontier,default)
S3method(get_frontier,psa)
S3method(get_matrix_order,eval_matrix)
S3method(get_matrix_order,uneval_matrix)
S3method(get_method,combined_model)
S3method(get_method,psa)
S3method(get_method,run_model)
S3method(get_model,psa)
S3method(get_model_results,combined_model)
S3method(get_model_results,psa)
S3method(get_n_indiv,combined_model)
S3method(get_n_indiv,default)
S3method(get_n_indiv,eval_strategy)
S3method(get_noncomparable_strategy,combined_model)
S3method(get_noncomparable_strategy,default)
S3method(get_noncomparable_strategy,psa)
S3method(get_noncomparable_strategy,run_model)
S3method(get_parameter_names,eval_parameters)
S3method(get_parameter_names,run_model)
S3method(get_parameter_names,uneval_parameters)
S3method(get_parameter_names,updated_model)
S3method(get_parameter_values,run_model)
S3method(get_parameter_values,updated_model)
S3method(get_root_strategy,combined_model)
S3method(get_root_strategy,default)
S3method(get_root_strategy,psa)
S3method(get_root_strategy,run_model)
S3method(get_state_names,array)
S3method(get_state_names,default)
S3method(get_state_names,eval_matrix)
S3method(get_state_names,eval_state_list)
S3method(get_state_names,part_surv)
S3method(get_state_names,run_model)
S3method(get_state_names,uneval_matrix)
S3method(get_state_names,uneval_model)
S3method(get_state_value_names,combined_model)
S3method(get_state_value_names,eval_state_list)
S3method(get_state_value_names,run_model)
S3method(get_state_value_names,state)
S3method(get_state_value_names,uneval_model)
S3method(get_state_value_names,uneval_state_list)
S3method(get_states,default)
S3method(get_transition,default)
S3method(get_uneval_inflow,default)
S3method(get_uneval_init,combined_model)
S3method(get_uneval_init,default)
S3method(get_uneval_init,psa)
S3method(get_values,combined_model)
S3method(get_values,eval_strategy)
S3method(get_values,list)
S3method(get_values,run_model)
S3method(get_values,updated_model)
S3method(has_state_time,part_surv)
S3method(has_state_time,state)
S3method(has_state_time,uneval_matrix)
S3method(has_state_time,uneval_parameters)
S3method(has_state_time,uneval_state_list)
S3method(interpolate,default)
S3method(interpolate,part_surv)
S3method(interpolate,state)
S3method(interpolate,uneval_matrix)
S3method(interpolate,uneval_state_list)
S3method(modify,state)
S3method(modify,uneval_matrix)
S3method(modify,uneval_parameters)
S3method(modify,uneval_state_list)
S3method(modify_,state)
S3method(modify_,uneval_matrix)
S3method(modify_,uneval_parameters)
S3method(modify_,uneval_state_list)
S3method(plot,combined_model)
S3method(plot,dsa)
S3method(plot,psa)
S3method(plot,run_model)
S3method(plot,surv_object)
S3method(plot,uneval_matrix)
S3method(plot,updated_model)
S3method(print,combined_model)
S3method(print,correlation_matrix)
S3method(print,dsa)
S3method(print,eval_matrix)
S3method(print,eval_state_list)
S3method(print,psa)
S3method(print,resamp_definition)
S3method(print,run_model)
S3method(print,sensitivity)
S3method(print,state)
S3method(print,summary_dsa)
S3method(print,summary_run_model)
S3method(print,summary_updated_model)
S3method(print,uneval_matrix)
S3method(print,uneval_model)
S3method(print,uneval_parameters)
S3method(print,uneval_state_list)
S3method(print,updated_model)
S3method(scale,updated_model)
S3method(set_states,default)
S3method(set_transition,default)
S3method(summary,combined_model)
S3method(summary,dsa)
S3method(summary,psa)
S3method(summary,run_model)
S3method(summary,surv_shift)
S3method(summary,updated_model)
S3method(to_dots,default)
S3method(to_dots,list)
S3method(update,run_model)
S3method(vswitch,character)
S3method(vswitch,default)
S3method(vswitch,factor)
export("%>%")
export(add_hazards)
export(add_hazards_)
export(apply_af)
export(apply_hr)
export(apply_or)
export(apply_shift)
export(calibrate_model)
export(close_cluster)
export(combine_probs)
export(compute_surv)
export(compute_surv_)
export(define_calibration_fn)
export(define_correlation)
export(define_distribution)
export(define_dsa)
export(define_inflow)
export(define_inflow_)
export(define_init)
export(define_init_)
export(define_parameters)
export(define_parameters_)
export(define_part_surv)
export(define_part_surv_)
export(define_psa)
export(define_psa_)
export(define_starting_values)
export(define_starting_values_)
export(define_state)
export(define_state_)
export(define_strategy)
export(define_strategy_)
export(define_surv_dist)
export(define_surv_fit)
export(define_surv_spline)
export(define_surv_table)
export(define_transition)
export(define_transition_)
export(discount)
export(dispatch_strategy)
export(export_savi)
export(get_counts)
export(get_values)
export(join)
export(join_)
export(load_surv_models)
export(look_up)
export(mix)
export(mix_)
export(modify)
export(or_to_prob)
export(part_survs_from_surv_inputs)
export(prob_to_prob)
export(rate_to_prob)
export(reindent_transition)
export(resample_surv)
export(rescale_discount_rate)
export(rescale_prob)
export(rr_to_prob)
export(run_bcea)
export(run_dsa)
export(run_model)
export(run_model_)
export(run_model_tabular)
export(run_psa)
export(set_covariates)
export(set_covariates_)
export(status_cluster)
export(use_cluster)
export(use_distribution)
importFrom(dplyr,"%>%")
importFrom(dplyr,anti_join)
importFrom(dplyr,as_data_frame)
importFrom(dplyr,as_tibble)
importFrom(dplyr,bind_rows)
importFrom(dplyr,desc)
importFrom(dplyr,funs)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n)
importFrom(dplyr,row_number)
importFrom(dplyr,tibble)
importFrom(dplyr,ungroup)
importFrom(ggplot2,"%+replace%")
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guides)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(grDevices,cairo_pdf)
importFrom(grDevices,dev.off)
importFrom(grDevices,png)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(mvnfast,rmvn)
importFrom(purrr,map)
importFrom(purrr,map_chr)
importFrom(purrr,map_dbl)
importFrom(purrr,map_lgl)
importFrom(rlang,"%||%")
importFrom(rlang,.data)
importFrom(rlang,as_label)
importFrom(rlang,as_quosure)
importFrom(rlang,as_quosures)
importFrom(rlang,call_match)
importFrom(rlang,caller_env)
importFrom(rlang,enexpr)
importFrom(rlang,enexprs)
importFrom(rlang,enquo)
importFrom(rlang,eval_tidy)
importFrom(rlang,expr)
importFrom(rlang,exprs)
importFrom(rlang,get_env)
importFrom(rlang,get_expr)
importFrom(rlang,is_quosure)
importFrom(rlang,new_quosure)
importFrom(rlang,parse_exprs)
importFrom(rlang,quo)
importFrom(rlang,quos)
importFrom(rlang,set_expr)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,dist)
importFrom(stats,ecdf)
importFrom(stats,formula)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,nls)
importFrom(stats,plogis)
importFrom(stats,pnorm)
importFrom(stats,qbeta)
importFrom(stats,qbinom)
importFrom(stats,qgamma)
importFrom(stats,qlnorm)
importFrom(stats,qlogis)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,reorder)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,var)
importFrom(tibble,tibble)
importFrom(tools,file_ext)
importFrom(utils,as.roman)
importFrom(utils,globalVariables)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
